/*	Hardware definitions for graphic LCD displays
	
		PA.0-7	I/O	LCD D0-7
	
		PE.0	Out	LCD E
		PE.4	Out	LCD ID
		PE.3	Out	LCD R/W_

		PE.1	Out	LCD CS1
		PE.7	Out	LCD CS2
*/

/* LCD control signals */
#define	LCD_CS1	1
#define	LCD_CS2	7
#define	LCD_E		0
#define	LCD_ID	4
#define	LCD_RW	3

/* LCD status bits */
#define BUSY	7


void MsDelay ( int iDelay )
{
	unsigned long ul0;
	ul0 = MS_TIMER;		// get current timer value
	while ( MS_TIMER < ul0 + (unsigned long) iDelay );
}

void UsDelay ( int iDelay )
{
	int i;
	iDelay /= 11;		// this is experimental, for a RCM2100
	for ( i=0; i<iDelay; i++ );
}


/* Low level functions */

void LCD_SelSide(int side)
{
	if(side)	{
		BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_CS2 );	// Rise CS2
		BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_CS1 );	// Lower CS1
	}
	else	{
		BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_CS1 );	// Rise CS1
		BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_CS2 );	// Lower CS2
	}
}

void LCD_CalcPage(int y,int *page,int *row)
{
	*page=(y>>3);				// page = integer part of y coord /8
	*row=y-((*page)<<3);		// row = remainder
}
	
void LCD_Write(int data)
{
	WrPortI ( PADR, &PADRShadow, data );		// write data
	WrPortI ( SPCR, &SPCRShadow, 0x84 );		// PA0-7 = Outputs, put data in bus
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_RW );	// Lower RW (Write)
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_E );	// Rise E
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_E );	// Lower E
}

int LCD_Read()
{
int data;
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_RW );	// Rise RW (Read)
	WrPortI ( SPCR, &SPCRShadow, 0x80 );		// PA0-7 = Inputs, remove data from bus
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_E ); // Rise E
	data=RdPortI ( PADR );		   // read data
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_E ); // Lower E
	return(data);
}

int LCD_Status()
{
int status;
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_ID );	// Lower ID (Cmd)
	do {
		status=LCD_Read();		   // read status (busy flag)
	} while(status&(1<<BUSY));		// loop while busy=1
	return(status);
}

int LCD_ReadData()
{
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_ID );	// Rise ID (Data)
	return(LCD_Read());
}

void LCD_WriteCmd(int cmd)
{
	LCD_Status();		// ID returns low
	LCD_Write(cmd);
}

void LCD_WriteData(int data)
{
	LCD_Status();
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_ID );	// Rise ID (Data)
	LCD_Write(data);
}

void LCD_init ()
{
	WrPortI ( PEDR,&PEDRShadow,0x00 );		// Make sure Outputs are Low
	WrPortI ( PEDDR,&PEDDRShadow,'\B10011011' );	// PE0,1,3,4,7 = output
	WrPortI ( PEFR, &PEFRShadow, 0 );		// PE: no I/O strobe
	MsDelay ( 1000 );				// wait for LCD to reset itself

	LCD_SelSide(1);
	LCD_WriteCmd ( '\B00111111' );			// Display on
	LCD_SelSide(0);
	LCD_WriteCmd ( '\B00111111' );			// Display on
}

/* High level functions */

void LCD_home ( void )
{
	LCD_SelSide(1);
	LCD_WriteCmd ('\B01000000');			// address 0
	LCD_WriteCmd ('\B11000000');			// display starts at address 0
	LCD_SelSide(0);
	LCD_WriteCmd ('\B01000000');			// address 0
	LCD_WriteCmd ('\B11000000');			// display starts at address 0
}

void LCD_fill(unsigned char pattern)
{
int i,page;
	LCD_home();										// address 0,0
	for(page=0;page<8;page++) {
		LCD_SelSide(0);							// select left
		LCD_WriteCmd (0xB8+page);				// set page address	
		for(i=0;i<64;i++)
			LCD_WriteData(pattern);				// fill with pattern
		LCD_SelSide(1);							// select right
		LCD_WriteCmd (0xB8+page);				// set page address	
		for(i=0;i<64;i++)
			LCD_WriteData(pattern);				// fill with pattern
	}
}

#define LCD_clear() LCD_fill(0)


void LCD_plot (int x, int y)
{
int page,row,data;
	LCD_SelSide(x>63);						// 0-63 => side 0; 63>127 => side 1
	x=(x>63)?(x-64):x;						// correct x address if >63
	LCD_WriteCmd (0x40+x);					// address = x or x-64
	LCD_CalcPage(y,&page,&row);			// calculate page and row within page
	LCD_WriteCmd (0xB8+page);				// set page address
	LCD_ReadData();							// dummy read after address setting
	data=LCD_ReadData();						// get data at that address
	data|=(1<<row);							// set requested bit
	LCD_WriteCmd (0x40+x);					// set address again (reading increments counter)
	LCD_WriteData(data);
}

void LCD_dump (unsigned char *imgdata)
{
int i,page;

	LCD_home();										// address 0,0
	for(page=0;page<8;page++) {
		LCD_SelSide(0);							// select left
		LCD_WriteCmd (0xB8+page);				// set page address	
		for(i=0;i<64;i++)
			LCD_WriteData(*(imgdata++));		// send left half for each page
		LCD_SelSide(1);							// select right
		LCD_WriteCmd (0xB8+page);				// set page address	
		for(i=0;i<64;i++)
			LCD_WriteData(*(imgdata++));		// send right half for each page
	}
}

void LCD_putchr ( char chr )
{
const static char font5x7[] = {
0x00, 0x00, 0x00, 0x00, 0x00,// (space)
0x00, 0x00, 0x5F, 0x00, 0x00,// !
0x00, 0x07, 0x00, 0x07, 0x00,// "
0x14, 0x7F, 0x14, 0x7F, 0x14,// #
0x24, 0x2A, 0x7F, 0x2A, 0x12,// $
0x23, 0x13, 0x08, 0x64, 0x62,// %
0x36, 0x49, 0x55, 0x22, 0x50,// &
0x00, 0x05, 0x03, 0x00, 0x00,// '
0x00, 0x1C, 0x22, 0x41, 0x00,// (
0x00, 0x41, 0x22, 0x1C, 0x00,// )
0x08, 0x2A, 0x1C, 0x2A, 0x08,// *
0x08, 0x08, 0x3E, 0x08, 0x08,// +
0x00, 0x50, 0x30, 0x00, 0x00,// ,
0x08, 0x08, 0x08, 0x08, 0x08,// -
0x00, 0x30, 0x30, 0x00, 0x00,// .
0x20, 0x10, 0x08, 0x04, 0x02,// /
0x3E, 0x51, 0x49, 0x45, 0x3E,// 0
0x00, 0x42, 0x7F, 0x40, 0x00,// 1
0x42, 0x61, 0x51, 0x49, 0x46,// 2
0x21, 0x41, 0x45, 0x4B, 0x31,// 3
0x18, 0x14, 0x12, 0x7F, 0x10,// 4
0x27, 0x45, 0x45, 0x45, 0x39,// 5
0x3C, 0x4A, 0x49, 0x49, 0x30,// 6
0x01, 0x71, 0x09, 0x05, 0x03,// 7
0x36, 0x49, 0x49, 0x49, 0x36,// 8
0x06, 0x49, 0x49, 0x29, 0x1E,// 9
0x00, 0x36, 0x36, 0x00, 0x00,// :
0x00, 0x56, 0x36, 0x00, 0x00,// ;
0x00, 0x08, 0x14, 0x22, 0x41,// <
0x14, 0x14, 0x14, 0x14, 0x14,// =
0x41, 0x22, 0x14, 0x08, 0x00,// >
0x02, 0x01, 0x51, 0x09, 0x06,// ?
0x32, 0x49, 0x79, 0x41, 0x3E,// @
0x7E, 0x11, 0x11, 0x11, 0x7E,// A
0x7F, 0x49, 0x49, 0x49, 0x36,// B
0x3E, 0x41, 0x41, 0x41, 0x22,// C
0x7F, 0x41, 0x41, 0x22, 0x1C,// D
0x7F, 0x49, 0x49, 0x49, 0x41,// E
0x7F, 0x09, 0x09, 0x01, 0x01,// F
0x3E, 0x41, 0x41, 0x51, 0x32,// G
0x7F, 0x08, 0x08, 0x08, 0x7F,// H
0x00, 0x41, 0x7F, 0x41, 0x00,// I
0x20, 0x40, 0x41, 0x3F, 0x01,// J
0x7F, 0x08, 0x14, 0x22, 0x41,// K
0x7F, 0x40, 0x40, 0x40, 0x40,// L
0x7F, 0x02, 0x04, 0x02, 0x7F,// M
0x7F, 0x04, 0x08, 0x10, 0x7F,// N
0x3E, 0x41, 0x41, 0x41, 0x3E,// O
0x7F, 0x09, 0x09, 0x09, 0x06,// P
0x3E, 0x41, 0x51, 0x21, 0x5E,// Q
0x7F, 0x09, 0x19, 0x29, 0x46,// R
0x46, 0x49, 0x49, 0x49, 0x31,// S
0x01, 0x01, 0x7F, 0x01, 0x01,// T
0x3F, 0x40, 0x40, 0x40, 0x3F,// U
0x1F, 0x20, 0x40, 0x20, 0x1F,// V
0x7F, 0x20, 0x18, 0x20, 0x7F,// W
0x63, 0x14, 0x08, 0x14, 0x63,// X
0x03, 0x04, 0x78, 0x04, 0x03,// Y
0x61, 0x51, 0x49, 0x45, 0x43,// Z
0x00, 0x00, 0x7F, 0x41, 0x41,// [
0x02, 0x04, 0x08, 0x10, 0x20,// "\"
0x41, 0x41, 0x7F, 0x00, 0x00,// ]
0x04, 0x02, 0x01, 0x02, 0x04,// ^
0x40, 0x40, 0x40, 0x40, 0x40,// _
0x00, 0x01, 0x02, 0x04, 0x00,// `
0x20, 0x54, 0x54, 0x54, 0x78,// a
0x7F, 0x48, 0x44, 0x44, 0x38,// b
0x38, 0x44, 0x44, 0x44, 0x20,// c
0x38, 0x44, 0x44, 0x48, 0x7F,// d
0x38, 0x54, 0x54, 0x54, 0x18,// e
0x08, 0x7E, 0x09, 0x01, 0x02,// f
0x08, 0x14, 0x54, 0x54, 0x3C,// g
0x7F, 0x08, 0x04, 0x04, 0x78,// h
0x00, 0x44, 0x7D, 0x40, 0x00,// i
0x20, 0x40, 0x44, 0x3D, 0x00,// j
0x00, 0x7F, 0x10, 0x28, 0x44,// k
0x00, 0x41, 0x7F, 0x40, 0x00,// l
0x7C, 0x04, 0x18, 0x04, 0x78,// m
0x7C, 0x08, 0x04, 0x04, 0x78,// n
0x38, 0x44, 0x44, 0x44, 0x38,// o
0x7C, 0x14, 0x14, 0x14, 0x08,// p
0x08, 0x14, 0x14, 0x18, 0x7C,// q
0x7C, 0x08, 0x04, 0x04, 0x08,// r
0x48, 0x54, 0x54, 0x54, 0x20,// s
0x04, 0x3F, 0x44, 0x40, 0x20,// t
0x3C, 0x40, 0x40, 0x20, 0x7C,// u
0x1C, 0x20, 0x40, 0x20, 0x1C,// v
0x3C, 0x40, 0x30, 0x40, 0x3C,// w
0x44, 0x28, 0x10, 0x28, 0x44,// x
0x0C, 0x50, 0x50, 0x50, 0x3C,// y
0x44, 0x64, 0x54, 0x4C, 0x44,// z
0x00, 0x08, 0x36, 0x41, 0x00,// {
0x00, 0x00, 0x7F, 0x00, 0x00,// |
0x00, 0x41, 0x36, 0x08, 0x00,// }
0x08, 0x08, 0x2A, 0x1C, 0x08,// ->
0x08, 0x1C, 0x2A, 0x08, 0x08 // <-
};
int i;
	for(i=0;i<5;i++)
		LCD_WriteData(font5x7[5*(chr-0x20)+i]);	// send character
	LCD_WriteData(0);										// send intercharacter separator	
}

void LCD_printat (unsigned int row, unsigned int col, char *ptr)
{
int x;
	do {
		x=(col>9)?6*(col-10):6*col;				// correct x address if col>9
		if(col>9)										// 0-9 => side 0; 10>20 => side 1
			LCD_SelSide(1);
		else {
			LCD_SelSide(0);
			x+=4;											// 4 pixels offset at both sides
		}
		LCD_WriteCmd (0xB8+row);					// set page address
		LCD_WriteCmd (0x40+x);						// address = 6*col or 6*col-10 (4 pixels offset)
		LCD_putchr (*ptr++);
		col++;
	} 	while (*ptr);
}

/* MAIN PROGRAM */

main()
{
int i,page,pepe;

const static unsigned char Cika[]= {
0xFF, 0x07, 0xFF, 0x0F, 0xFF, 0x27, 0xDF, 0x2F, 0xF7, 0x2F, 0xCF, 0x3F, 0xE7, 0x1F, 0xEF, 0x37, 
0xEF, 0x0F, 0xFF, 0x2F, 0xDF, 0xAF, 0x3F, 0xEF, 0x2F, 0xCF, 0x3F, 0xEF, 0x1F, 0xEF, 0x3F, 0xCF, 
0xBF, 0x2F, 0xEF, 0x2F, 0xFF, 0x0F, 0xFF, 0xAF, 0x5F, 0xBF, 0x6F, 0xBF, 0x6F, 0xDF, 0x2F, 0xFF, 
0xAF, 0xBF, 0x7F, 0xEF, 0xDF, 0x3F, 0xEF, 0xBF, 0xEF, 0x3F, 0xDF, 0xFF, 0xBF, 0xEF, 0xBF, 0xFF, 
0xBF, 0xEF, 0x7F, 0xDF, 0xFF, 0xBF, 0xFF, 0xEF, 0xBF, 0x7F, 0xFF, 0xEF, 0xBF, 0xFF, 0x7F, 0xFF, 
0xEF, 0x7F, 0xFF, 0xEF, 0xFF, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0x55, 0xAD, 0xFB, 0x05, 0xFE, 0xA9, 0x57, 0xAD, 0xFA, 0x05, 0xFF, 0xA9, 0xAE, 0x51, 0xA9, 0x01, 
0xFE, 0xC9, 0xB5, 0xEF, 0xC8, 0xB9, 0xE5, 0xD9, 0xB5, 0xCE, 0xB1, 0x69, 0xD4, 0xE9, 0xD7, 0xB4, 
0x4D, 0xFB, 0xD0, 0xA9, 0xDD, 0xE1, 0xDC, 0xAB, 0xD5, 0xE9, 0xD5, 0xA8, 0xD5, 0x77, 0xCD, 0xF2, 
0xD9, 0xA4, 0x79, 0xC7, 0xFC, 0xCB, 0xA9, 0xF4, 0xC9, 0xB5, 0xDF, 0xF2, 0xCF, 0xB4, 0xE9, 0xD3, 
0xAC, 0xD5, 0xF7, 0xCF, 0xB8, 0xD1, 0xED, 0xB1, 0xCD, 0xF7, 0xAF, 0xD1, 0xED, 0xD9, 0xA1, 0xDF, 
0xEF, 0xD1, 0x79, 0xC5, 0xF9, 0xD7, 0xAE, 0xD7, 0xFD, 0xC1, 0xB9, 0xD5, 0xFD, 0xF7, 0x9F, 0x77, 
0xDF, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xBD, 0x76, 0x89, 0xF7, 0x9C, 0x73, 0xCD, 0x36, 0xF9, 0x87, 0x7C, 0xB3, 0xCE, 0x39, 0xE6, 0x55, 
0xFF, 0xDD, 0xFF, 0x7F, 0xFD, 0xF7, 0xDF, 0xFF, 0xF5, 0xBF, 0xFF, 0x3B, 0x1F, 0x1F, 0x9B, 0x9F, 
0x1F, 0x9B, 0x2F, 0x9F, 0xBE, 0x1B, 0x17, 0xFF, 0xFE, 0xDF, 0xFD, 0xBF, 0xFB, 0xFF, 0xDF, 0xFB, 
0xBF, 0xEF, 0xFF, 0xDF, 0xFB, 0x3D, 0x2F, 0x3F, 0x3B, 0xAF, 0x3F, 0x1B, 0xBF, 0x2F, 0x3E, 0x3F, 
0x2F, 0x3F, 0x3D, 0x3F, 0x3F, 0x3F, 0x3D, 0x2F, 0xFF, 0x3F, 0x2F, 0x1A, 0x3F, 0x3F, 0x2B, 0x3F, 
0x1E, 0x3F, 0x7B, 0xFF, 0xF7, 0xFF, 0xDF, 0xFD, 0xFF, 0xDF, 0xFB, 0xFF, 0xFF, 0xFF, 0x22, 0xDD, 
0xAA, 0x55, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xB5, 0xD6, 0x2D, 0xF2, 0x8E, 0x75, 0x96, 0xFD, 0x02, 0xFD, 0x96, 0xD5, 0xBE, 0x61, 0xB6, 0x4D, 
0xF7, 0x7F, 0xFF, 0xFF, 0xED, 0xBF, 0xFF, 0xFD, 0xFF, 0xFB, 0xC0, 0xC0, 0x80, 0x1E, 0x2F, 0x3F, 
0x3F, 0x3F, 0x9E, 0x49, 0x01, 0x00, 0x00, 0xE7, 0xC3, 0x91, 0x3D, 0x3F, 0x4D, 0x4C, 0x6D, 0xC3, 
0x01, 0x7B, 0xBF, 0xFF, 0xFF, 0x80, 0x80, 0xAA, 0x84, 0x9B, 0xDE, 0x84, 0x9A, 0x96, 0xCE, 0x9D, 
0x80, 0xA2, 0x88, 0x97, 0x81, 0x8F, 0x8F, 0xD1, 0xD5, 0xC1, 0xD9, 0xD3, 0xCF, 0xC1, 0xC9, 0xCB, 
0xC0, 0xC0, 0xFF, 0xFF, 0xF7, 0xBE, 0xFF, 0xF7, 0xBF, 0xFE, 0x77, 0xFF, 0xFF, 0xFF, 0x22, 0xDD, 
0xAA, 0x55, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0x7E, 0xC3, 0xBC, 0x57, 0xEA, 0x55, 0xDE, 0xB3, 0x5C, 0xE3, 0x9E, 0x72, 0xCF, 0x38, 0xE7, 0x55, 
0xFF, 0xFF, 0xED, 0xFF, 0xFF, 0xB7, 0xFE, 0xFF, 0xFF, 0x71, 0x73, 0x73, 0x73, 0x73, 0x71, 0x73, 
0x73, 0xF3, 0x73, 0xF3, 0xF3, 0x73, 0xF3, 0xF3, 0x73, 0xF3, 0xF3, 0xF3, 0xB3, 0xF3, 0xF3, 0xB3, 
0x7B, 0xF3, 0xE7, 0xC3, 0xE7, 0xE7, 0xA7, 0xE5, 0xE7, 0xA7, 0x67, 0x65, 0xE7, 0xE7, 0xE5, 0x67, 
0xE3, 0xE7, 0x67, 0xE7, 0xF3, 0x73, 0x73, 0xB3, 0xFF, 0xF3, 0xF3, 0xB3, 0xF3, 0xF2, 0x73, 0xF3, 
0xF3, 0xDE, 0xFF, 0xDF, 0x7D, 0xFF, 0xF7, 0xDD, 0xFF, 0xF7, 0xBF, 0xFF, 0xFF, 0xFF, 0x22, 0xDD, 
0xAA, 0x55, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0x7D, 0xC2, 0x3F, 0xD0, 0x6F, 0x92, 0x7D, 0xD2, 0x6F, 0x90, 0x7F, 0xC2, 0x3D, 0xEB, 0x96, 0x75, 
0xFF, 0x6F, 0xFE, 0xFF, 0xF7, 0xDF, 0xFF, 0xFE, 0xBF, 0xFB, 0x00, 0x00, 0x00, 0xE6, 0xE7, 0x66, 
0xEF, 0xD2, 0xBD, 0x07, 0x07, 0x5B, 0xDB, 0xD7, 0xC3, 0x0F, 0x07, 0x75, 0xFB, 0xEB, 0xFF, 0xBB, 
0x40, 0xFF, 0xFB, 0x06, 0x03, 0xF5, 0xFB, 0x07, 0x07, 0xDA, 0xFA, 0xFB, 0xF5, 0x07, 0x03, 0x13, 
0x77, 0xFB, 0xFD, 0x07, 0xFF, 0x02, 0x53, 0x07, 0xF7, 0xFA, 0xEB, 0xFD, 0x27, 0x3B, 0x9B, 0xDB, 
0x07, 0xFE, 0xFF, 0x77, 0xFF, 0xFF, 0xED, 0xBF, 0xFF, 0xFD, 0xEF, 0xFF, 0xFF, 0xFF, 0x22, 0xDD, 
0xAA, 0x55, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0x7F, 0x40, 0x7F, 0xCA, 0x33, 0xEC, 0x4B, 0x7E, 0xC1, 0x3E, 0xCB, 0x32, 0xEF, 0xD8, 0x27, 0xDD, 
0xF7, 0x7F, 0xFF, 0x3F, 0x5D, 0xF7, 0xFF, 0xBF, 0x7F, 0xF6, 0xFE, 0xFE, 0x7E, 0xEC, 0xFE, 0x7E, 
0xFE, 0xF6, 0xDF, 0xFF, 0xFE, 0xB6, 0xFE, 0xFC, 0xEE, 0xFF, 0xFF, 0xF6, 0xBC, 0xFE, 0xDC, 0xFF, 
0xBE, 0xF4, 0xFE, 0xAE, 0x7A, 0xFF, 0xF7, 0xDF, 0xFF, 0x5C, 0xFE, 0xFC, 0xAE, 0x7F, 0xFE, 0xDD, 
0xFF, 0x7B, 0xEF, 0xFE, 0xFF, 0xDC, 0x7F, 0xFE, 0xFA, 0x6E, 0xFC, 0xFE, 0x6E, 0xFC, 0xFE, 0xAE, 
0xFC, 0xFE, 0xDF, 0x7B, 0xFF, 0xFF, 0xED, 0xFF, 0x7F, 0xFF, 0xEE, 0xFF, 0xFF, 0xFF, 0x22, 0xDD, 
0xAA, 0x55, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0x6B, 0xCD, 0x3B, 0xEA, 0xAF, 0x32, 0xED, 0x2B, 0xFD, 0x4B, 0xBA, 0x63, 0xBE, 0x67, 0x8F, 0x4E, 
0xBF, 0x6F, 0x0E, 0x4F, 0x0F, 0x6F, 0x8F, 0x6F, 0x3F, 0xCF, 0x0F, 0x4F, 0xAF, 0x4F, 0x37, 0xCF, 
0x0F, 0x4F, 0x2E, 0x4F, 0x4F, 0xBF, 0x6E, 0x0F, 0x4D, 0x2F, 0xCF, 0x2F, 0x6F, 0xAE, 0x0F, 0x6F, 
0x0F, 0x6D, 0x57, 0xFF, 0x0F, 0xAF, 0x46, 0xAF, 0x4F, 0x57, 0xFF, 0x0F, 0xAF, 0x4F, 0xAB, 0x2F, 
0xCF, 0x7F, 0x8D, 0x6F, 0x8F, 0x6F, 0x97, 0x6F, 0xAF, 0x2F, 0xCF, 0x37, 0x4F, 0xCF, 0x3F, 0xED, 
0x2F, 0xCF, 0x2F, 0xCF, 0x2F, 0xDB, 0x2F, 0xCF, 0x2F, 0x57, 0xCF, 0x7F, 0xCF, 0x3F, 0x42, 0xFD, 
0x4A, 0xF5, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
};

const static unsigned char rabbit[] = {
0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x10, 0x08, 0x00, 0x10, 0x10, 0x20, 0x20, 
0x40, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0x40, 0x78, 0x68, 0x48, 0x48, 0x48, 0x48, 0x48, 0x08, 
0x08, 0x08, 0x08, 0x10, 0x10, 0x10, 0x20, 0x60, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0xC0, 0x40, 0x20, 0x38, 0x24, 0x04, 0x42, 0x44, 0x44, 0x44, 0x44, 0x40, 0x48, 
0x48, 0x48, 0x48, 0x48, 0x48, 0x44, 0x44, 0x84, 0x05, 0x3E, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, 0x04, 0x04, 0x04, 0x04, 0x08, 0x08, 0x08, 0x08, 
0x08, 0x08, 0x08, 0x08, 0x08, 0x09, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0C, 
0x0C, 0x04, 0x04, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x02, 0x02, 0x32, 0x04, 
0x04, 0x08, 0x08, 0x10, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x07, 0x08, 0x10, 0x10, 0x10, 0x10, 0x20, 0x20, 0x20, 0x20, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x08, 0x08, 0x10, 0x20, 0x20, 0x40, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x80, 0xC0, 0x40, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x08, 0x0C, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x02, 0x02, 
0x02, 0x02, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, 0x04, 
0x04, 0x04, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x04, 0x04, 0x18, 0x20, 0x40, 
0x80, 0x80, 0x80, 0x00, 0xC0, 0xC0, 0xA3, 0x22, 0x02, 0x02, 0x11, 0x31, 0x31, 0x31, 0x31, 0x31, 
0x31, 0x21, 0x21, 0x22, 0x1C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x02, 0x02, 0x02, 0x02, 
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
};
const static unsigned char RabbitBanner[] = {
0xFF, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0xFF, 0x0F, 
0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xFC, 0x3E, 
0x02, 0x02, 0x02, 0x02, 0x82, 0xC2, 0xC2, 0xC2, 0xC2, 0x02, 0x02, 0x02, 0x06, 0x0C, 0xF8, 0xE0, 
0x00, 0x00, 0x00, 0x80, 0xC0, 0xF0, 0x3C, 0x0C, 0x06, 0x02, 0x02, 0x82, 0x02, 0x02, 0x02, 0x06, 
0xFE, 0x80, 0x00, 0x00, 0xE0, 0xFC, 0xFC, 0x06, 0x02, 0x02, 0x02, 0x02, 0xC2, 0xC2, 0xC2, 0xC2, 
0x02, 0x02, 0x02, 0x06, 0x04, 0x18, 0xF8, 0xFC, 0x3E, 0x02, 0x02, 0x02, 0x02, 0x82, 0xC2, 0xC2, 
0xC2, 0xC2, 0x02, 0x02, 0x02, 0x06, 0x0C, 0xF8, 0xF0, 0xFC, 0x7E, 0x02, 0x02, 0x02, 0x02, 0x02, 
0xF2, 0xFE, 0xFE, 0xC2, 0xC2, 0xC2, 0xC2, 0x02, 0x02, 0x02, 0x02, 0x02, 0xC2, 0xC2, 0xC2, 0xC2, 
0xC2, 0x62, 0x3E, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x80, 
0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0xFF, 0xFF, 0x07, 0x00, 
0x00, 0x00, 0x00, 0xE0, 0xC3, 0xC3, 0x03, 0x01, 0x01, 0x00, 0x18, 0xF8, 0x98, 0x0C, 0x07, 0xC1, 
0xF0, 0x38, 0x1E, 0x07, 0x01, 0x00, 0x00, 0x00, 0x10, 0x1C, 0x1F, 0x1F, 0x00, 0x00, 0x00, 0x00, 
0x01, 0x7F, 0xE0, 0xFC, 0xFF, 0x1F, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xE1, 0xE1, 0xE1, 0x01, 
0x00, 0x00, 0x08, 0x0C, 0xF6, 0xFF, 0xFF, 0x07, 0x00, 0x00, 0x00, 0x00, 0xE0, 0xE1, 0xE1, 0xE1, 
0xE1, 0x01, 0x00, 0x00, 0x08, 0x1C, 0xF6, 0xFF, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x7F, 
0x03, 0x01, 0x01, 0xF9, 0xFF, 0x3F, 0x03, 0x00, 0x00, 0x00, 0x00, 0xF8, 0x1F, 0x01, 0x01, 0x01, 
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x80, 
0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xFE, 0xFF, 0xFF, 0xE0, 0xE0, 0xE0, 
0xE0, 0x20, 0x3E, 0x07, 0x7F, 0xFF, 0xFE, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xFF, 0xFE, 0xEF, 0xE3, 
0xE0, 0xE0, 0xE0, 0x20, 0x38, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xFE, 0xFE, 0xFE, 0xE0, 0xE0, 0xE0, 
0xE0, 0xE0, 0xFF, 0xFF, 0xE3, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE1, 0xE1, 0xE1, 0xE1, 0x60, 0x60, 
0x70, 0x30, 0x98, 0xFC, 0xFF, 0xFF, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE1, 0xE1, 0xE1, 0xE1, 
0x60, 0x60, 0x30, 0x30, 0x98, 0xFE, 0xFF, 0xFF, 0xE1, 0xE0, 0xE0, 0xE0, 0x60, 0x3C, 0x0F, 0x00, 
0x00, 0xE0, 0xFF, 0xFF, 0xE7, 0xE0, 0xE0, 0xE0, 0xE0, 0x20, 0x3F, 0x01, 0x38, 0x00, 0x10, 0x38, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 
0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0xC8, 0x00, 
0x00, 0x00, 0x00, 0x00, 0xE0, 0xE0, 0x80, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x20, 0xE0, 0x20, 0xE0, 
0x00, 0x00, 0x00, 0x00, 0x00, 0xE8, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x20, 0x00, 0x00, 0x00, 
0x00, 0x80, 0xE0, 0x60, 0xC0, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x40, 0xE0, 0x00, 0x00, 0x00, 0x00, 
0x00, 0xC0, 0x20, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x00, 0xE0, 0x00, 0x00, 0x00, 0x00, 
0x80, 0xE0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x20, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x20, 
0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 
0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x03, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x07, 0x00, 0x07, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 
0x00, 0x01, 0x07, 0x06, 0x03, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x03, 0x04, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x06, 0x07, 0x00, 0x00, 0x00, 0x00, 
0x01, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 
0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 
0x3F, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x3F, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
};


	LCD_init();
	while(1){

		LCD_clear();
		MsDelay ( 3000 );						// wait 3 secs
		LCD_fill(0xFF);						// black fill
		MsDelay ( 3000 );						// wait 3 secs
		LCD_clear();

		for(i=0;i<128;i++)
			LCD_plot(i,32); 					// x axis
		for(i=0;i<64;i++)
			LCD_plot(64,i); 					// y axis
		for(i=-64;i<63;i++)
			LCD_plot(64+i,32-(int)(32*(sin(i*3.14159/64)))); // plot sin(x); 0,0 is at top left
		LCD_printat(0,0,"sin(x)");
		MsDelay ( 3000 );						// wait 3 secs
		LCD_dump(Cika);	
		MsDelay ( 3000 );						// wait 3 secs
		LCD_dump(RabbitBanner);	
		LCD_printat(7,2,"Cika Electronica");
		MsDelay ( 3000 );						// wait 3 secs
		LCD_dump(rabbit);	
		LCD_printat(0,0,"Rabbit Semiconductor");
		LCD_printat(7,2,"Cika Electronica");
		MsDelay ( 3000 );						// wait 3 secs
	}
}
